--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define model
AuctionModel = {};
AuctionModel.__index = AuctionModel;

-- Create model.
function AuctionModel:Create(item, goldMinimum, goldStep, mustCarryGold, dkpStep, dkpBonusRaidMaximum, dkpThreshold,
    bidTime, isTest, greedMode)
    local auction = {
        id = addon:GetService("message"):GenerateString(30),
        started = time(),
        item = {
            id = item:GetItemID(),
            name = item:GetItemName(),
            link = item:GetItemLink(),
            icon = item:GetItemIcon()
        },
        goldMinimum = goldMinimum,
        goldStep = goldStep,
        mustCarryGold = mustCarryGold,
        dkpStep = dkpStep,
        dkpBonusRaidMaximum = dkpBonusRaidMaximum,
        dkpThreshold = dkpThreshold,
        bidTime = bidTime,
        participants = {},
        bids = {},
        rolls = {},
        winner = nil,
        isTest = isTest,
        greedMode = greedMode
    };
    setmetatable(auction, AuctionModel);
    return auction;
end

-- get names of all participants
function AuctionModel:GetParticipantNames()
    local names = {};
    for i, participant in ipairs(self.participants) do
        table.insert(names, participant.name);
    end
    return names;
end

-- get last bid
function AuctionModel:GetLastBid()
    -- check amount of bids
    if (#self.bids == 0) then
        return {
            players = {},
            gold = 0,
            dkp = 0,
            isGreed = true
        };
    end

    -- get last bid
    return self.bids[#self.bids];
end

-- add bid
function AuctionModel:AddBid(player, gold, dkp, isGreed)
    -- create bid
    local bid = {
        players = {player},
        gold = gold,
        dkp = dkp,
        isGreed = isGreed
    };

    -- add bid
    table.insert(self.bids, bid);
    return bid;
end

-- register model
addon:RegisterModel(AuctionModel, "auction");
