--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define model
LocalesModel = {};
LocalesModel.__index = LocalesModel;

-- Create model.
function LocalesModel:Create()
    -- define en locale
    return {
        ["en"] = {
            ["AddonLoaded"] = "Version " .. addon.version .. " loaded. Use /dlm for more informations.",
            ["NotAllowedToStartQueue"] = "Not startet. Your must be the Loot Master.",
            ["VersionOutdated"] = "Your version is outdated. The latest version can be downloaded from https://www.curseforge.com/wow/addons/dkp-loot-master.",
            ["Version"] = "Version",
            ["AddonRequired"] = "The DKP Loot Master addon is not installed. The latest version can be downloaded from https://www.curseforge.com/wow/addons/dkp-loot-master.",
            ["CurrentBid"] = "Current bid",
            ["NoCurrentBid"] = "No bids have been submitted so far.",
            ["PlayerRolled"] = "%s rolls %s",
            ["NoBidsFor"] = "No bids for %s.",
            ["NoBids"] = "No bids",
            ["PlayerWins"] = "%s wins.",
            ["PlayerWinsItem"] = "%s wins %s for %s %s%s.",
            ["ImportDkpData"] = "Import / Export DKP",
            ["ImportDkpDataDescription"] = "The DKP data is imported or exported in the following format:\n[Main character],[Twink],[...]:[DKP with Bonus DKP].",
            ["Time"] = "Time",
            ["FindItem"] = "Find Item",
            ["Item"] = "Item",
            ["Winner"] = "Winner",
            ["DateFormat"] = "%m/%d/%Y",
            ["TimeFormat"] = "%m/%d/%Y %I:%M%p",
            ["Date"] = "Date",
            ["Search"] = "Search",
            ["StartMasterLooter"] = "Start Master Looter",
            ["Gold"] = "Gold",
            ["Dkp"] = "DKP",
            ["BonusDkp"] = "Bonus DKP",
            ["Players"] = "Players",
            -- commands
            ["CommandsTitle"] = "Possible commands:\n",
            ["CommandsSettings"] = "/dlm settings - Show Loot Master settings.",
            ["CommandsHistory"] = "/dlm history - Show auction history.",
            ["CommandsStart"] = "/dlm start - Start Loot Master.",
            ["CommandsDkp"] = "/dlm dkp - Manage Loot Master dkp list.",
            -- history
            ["History"] = "History",
            ["HistoryExport"] = "Export",
            ["HistoryExportDescription"] = "The history is exported in the following format:\n[Date],[Time],[Character],[Item],[DKP],[Gold]",
            ["HistoryShowCourse"] = "Show course",
            ["HistoryFilterBy"] = "Filter by %s",
            ["HistoryRemoveEntry"] = "Remove entry",
            ["HistoryRemoveEntryQuestion"] = "Should the entry really be removed?",
            -- bid
            ["Bid"] = "Bid",
            ["BidNow"] = "Bid now!",
            ["BidMaxDkp"] = "Maximum DKP: %d",
            ["BidPlaced"] = "Bid placed",
            ["BidPass"] = "Pass",
            ["BidAutoPass"] = "Auction of %s is running. You automatically passed.",
            ["BidCannotBid"] = "Auction of %s is running. You can't bid.",
            ["BidItemInInventory"] = "Auction of %s is running. You already own the item.",
            ["BidNeed"] = "Main Spec",
            ["BidGreed"] = "Second Spec",
            -- queue
            ["QueueLootMaster"] = "Loot Master",
            ["QueueAskStart"] = "Do you want to use DLM to auction your loot?",
            ["QueueAlreadyRunning"] = "Loot Master already running.",
            ["QueueStarted"] = "Loot Master started. Your loot is now recorded.",
            ["QueueStopped"] = "Loot Master finished. Your loot is no longer recorded.",
            ["QueueStartedBy"] = "%s has started the DLM Master Looter. Your DKP stand: %d",
            ["QueueStartAuctions"] = "Start auctions",
            ["QueueRemoveItem"] = "Remove item",
            ["QueueWatching"] = "Just loot or drag items here.",
            ["QueueItemOpen"] = "1 Item open",
            ["QueueItemsOpen"] = "%d Items open",
            ["QueueInvalidItem"] = "This item cannot be auctioned.",
            ["QueueShowPlayerList"] = "Show Player List",
            ["QueueEndLootMaster"] = "End Loot Master",
            ["QueueEndLootMasterQuestion"] = "Should the DLM Loot Master really be ended?",
            ["QueueShowItems"] = "Show Items",
            -- auction
            ["Auction"] = "Auction",
            ["AuctionStarted"] = "Auction started.",
            ["AuctionEndsIn"] = "Auction ends in: ",
            -- stocks
            ["Stocks"] = "Stocks",
            ["StocksStartTestAuction"] = "Test Auction",
            ["StocksStart"] = "Start",
            ["StocksShowHistory"] = "Show History",
            ["StocksShowHistoryOfPlayer"] = "Shows all auctions that this player has won.",
            ["StocksResetDkp"] = "Reset DKP",
            ["StocksResetDkpOfPlayer"] = "Sets the DKP of %s to %d DKP depending on the Bonus DKP.",
            ["StocksResetDkpOfPlayerQuestion"] = "Should %s's DKP be set to %d?",
            ["StocksResetDkpOfPlayers"] = "Sets the DKP of all players depending on their Bonus DKP to %d - %d DKP.",
            ["StocksResetDkpOfPlayersQuestion"] = "Should the DKP of all players be set to %d - %d DKP depending on their Bonus DKP?",
            ["StocksCheckVersion"] = "Check version",
            ["StocksCheckVersionAgain"] = "Check addon version of %s again.",
            ["StocksSharedDKP"] = "Shared DKP",
            ["StocksAssignMain"] = "Assign Main Character",
            ["StocksAssignMainDescription"] = "If this character is a twink of an already known character, this character can be assigned to the main character as a twink. The DKP status is then shared between the characters.",
            ["StocksDetachTwink"] = "Detach Twink",
            ["StocksDetachTwinkDescription"] = "If the DKP status of one of the twinks is no longer to be shared with the main character, it can be detached and managed separately or deleted.",
            ["StocksRemovePlayer"] = "Remove Player",
            ["StocksSelectMainCharacter"] = "Please select the main character to which |cff00ff00%s|r should be assigned as twink.",
            ["StocksSelectTwink"] = "Please select the twink to be detached from |cff00ff00%s|r.",
            ["StocksImportExport"] = "Import / Export",
            ["StocksImportExportDescription"] = "Import existing account balances to DLM or export the current DLM account balances.",
            -- settings
            ["Settings"] = "Loot Master Settings",
            ["SettingsDescription"] = "Specify the system according to which items are to be auctioned.",
            ["SettingsSystemGoldOnly"] = "Gold Only",
            ["SettingsSystemGoldOnlyDescription"] = "Items are auctioned for gold only (GDKP). No DKP need to be managed.",
            ["SettingsSystemDkpOnly"] = "DKP Only",
            ["SettingsSystemDkpOnlyDescription"] = "Items are auctioned off for DKP. Gold bids are not possible.",
            ["SettingsSystemGoldAndDkp"] = "Gold + DKP",
            ["SettingsSystemGoldAndDkpDescription"] = "Items are auctioned for gold or DKP. Once DKP has been bid, the item can no longer be auctioned with gold.",
            ["SettingsGreedModeDisabled"] = "Disabled",
            ["SettingsGreedModeDisabledDescription"] = "Main > Second is not considered.",
            ["SettingsGreedModeEnabled"] = "Enabled",
            ["SettingsGreedModeEnabledDescription"] = "Before the auction, players are asked if the item is suitable for their Main or Second Spec. As soon as a player with Main Spec bids, players with Second Spec can no longer bid.",
            ["SettingsGreedModeDkpOnly"] = "Only for DKP",
            ["SettingsGreedModeDkpOnlyDescription"] = "Before the auction, players are asked if the item is suitable for their Main or Second Spec. Once a player with Main Spec bids DKP, players with Second Spec can no longer bid. Gold can be bid for by any player.",
            ["SettingsGreedModeGoldAndDkp"] = "For DKP + Gold",
            ["SettingsGreedModeGoldAndDkpDescription"] = "Before the auction, players are asked if the item is suitable for their Main or Second Spec. Once a player with Main Spec bids gold, players with Second Spec can no longer bid gold, but can still bid DKP. The same is then true for DKP.",
            ["SettingsGreedModeMainSpecDkpOnly"] = "Main Spec only DKP",
            ["SettingsGreedModeMainSpecDkpOnlyDescription"] = "Before the auction, players are asked if the item is suitable for their Main or Second Spec. Players with a Main Spec must bid DKP, players with a Second Spec can also bid Gold, but must pass as soon as a player with a Main Spec bids DKP.",
            ["SettingsDkpIncrease"] = "Increase per bid",
            ["SettingsDkpThreshold"] = "Bonus DKP Threshold",
            ["SettingsDkpThresholdDescription"] = "Defines the threshold at which no normal DKP but bonus DKP must be bid. Bonus DKPs are always bid in increments of 1. From this threshold, multiple players can bid the same number of DKP. The winner is then determined by rolling the dice.",
            ["SettingsDkpMaxRaid"] = "Maximum per Raid",
            ["SettingsDkpMaxRaidDescription"] = "The maximum amount of Bonus DKP a player can take and spend during a raid. This does not mean the amount of Bonus DKP a player can collect at all.",
            --["SettingsDkpMaxSavable"] = "Maximum Bonus DKP that can be saved",
            --["SettingsUnlimited"] = "Unlimited",
            --["SettingsUnlimitedDescription"] = "Indicates whether players can accumulate an unlimited number of Bonus DKP.",
            ["SettingsGoldMinBid"] = "Minimum bid",
            ["SettingsGoldIncrease"] = "Increase per bid",
            ["SettingsMustCarryGold"] = "Players must carry the gold with them",
            ["SettingsMustCarryGoldDescription"] = "Indicates whether the addon should check the player's inventory and only accept gold bids that the player can pay directly.",
            -- raid end
            ["RaidEnd"] = "End of Raid",
            ["By"] = "by",
            ["All"] = "All",
            ["Yes"] = "Yes",
            ["No"] = "No",
            ["New"] = "New",
            ["Ok"] = "OK",
            ["Close"] = "Close"
        },
        -- define de locale
        ["de"] = {
            ["AddonLoaded"] = "Version " .. addon.version .. " geladen. Benutze /dlm für weitere Informationen.",
            ["NotAllowedToStartQueue"] = "Nicht gestartet. Du musst der Plündermeister sein.",
            ["VersionOutdated"] = "Deine Version ist veraltet. Die neueste Version kann unter https://www.curseforge.com/wow/addons/dkp-loot-master heruntergeladen werden.",
            ["Version"] = "Version",
            ["AddonRequired"] = "Das DKP Loot Master-Addon ist nicht installiert. Die neueste Version kann unter https://www.curseforge.com/wow/addons/dkp-loot-master heruntergeladen werden.",
            ["CurrentBid"] = "Aktuelles Gebot",
            ["NoCurrentBid"] = "Bisher wurde kein Gebot abgegeben.",
            ["PlayerRolled"] = "%s würfelt. Ergebnis: %s",
            ["NoBidsFor"] = "Keine Gebote für %s.",
            ["NoBids"] = "Keine Gebote",
            ["PlayerWins"] = "%s gewinnt.",
            ["PlayerWinsItem"] = "%s gewinnt %s für %s %s%s.",
            ["ImportDkpData"] = "DKP importieren / exportieren",
            ["ImportDkpDataDescription"] = "Die DKP Daten werden in folgendem Format importiert bzw. exportiert:\n[Hauptcharakter],[Twink],[Twink],[...]:[DKP mit Bonus DKP]",
            ["Time"] = "Zeitpunkt",
            ["FindItem"] = "Gegenstand finden",
            ["Item"] = "Gegenstand",
            ["Winner"] = "Gewinner",
            ["DateFormat"] = "%d.%m.%Y",
            ["TimeFormat"] = "%d.%m.%Y %H:%M",
            ["Date"] = "Datum",
            ["Search"] = "Suchen",
            ["StartMasterLooter"] = "Plündermeister starten",
            ["Gold"] = "Gold",
            ["Dkp"] = "DKP",
            ["BonusDkp"] = "Bonus-DKP",
            ["Players"] = "Spieler",
            -- commands
            ["CommandsTitle"] = "Mögliche Befehle:",
            ["CommandsSettings"] = "/dlm settings - Plündermeister Einstellungen anzeigen.",
            ["CommandsHistory"] = "/dlm history - Historie anzeigen.",
            ["CommandsStart"] = "/dlm start - Plündermeister starten.",
            ["CommandsDkp"] = "/dlm dkp - Plündermeister DKP-Liste verwalten.",
            -- history
            ["History"] = "Historie",
            ["HistoryExport"] = "Exportieren",
            ["HistoryExportDescription"] = "Die Historie wird in folgendem Format exportiert:\n[Datum],[Uhrzeit],[Charakter],[Gegenstand],[DKP],[Gold]",
            ["HistoryShowCourse"] = "Zeige Verlauf",
            ["HistoryFilterBy"] = "Filtern nach %s",
            ["HistoryRemoveEntry"] = "Eintrag entfernen",
            ["HistoryRemoveEntryQuestion"] = "Soll der Eintrag wirklich entfernt werden?",
            -- bid
            ["Bid"] = "Gebot",
            ["BidNow"] = "Jetzt bieten!",
            ["BidMaxDkp"] = "Maximale DKP: %d",
            ["BidPlaced"] = "Gebot",
            ["BidPass"] = "Passen",
            ["BidAutoPass"] = "Auktion von %s läuft. Du hast automatisch gepasst.",
            ["BidCannotBid"] = "Auktion von %s läuft. Du kannst nicht mitbieten.",
            ["BidItemInInventory"] = "Auktion von %s läuft. Du besitzt den Gegenstand bereits.",
            ["BidNeed"] = "Main Spec",
            ["BidGreed"] = "Second Spec",
            -- queue
            ["QueueLootMaster"] = "Plündermeister",
            ["QueueAskStart"] = "Möchtest du DLM verwenden, um eure Beute zu versteigern?",
            ["QueueAlreadyRunning"] = "Plündermeister läuft bereits.",
            ["QueueStarted"] = "Plündermeister gestartet. Deine Beute wird jetzt aufgezeichnet.",
            ["QueueStopped"] = "Plündermeister beendet. Deine Beute wird nicht mehr aufgezeichnet.",
            ["QueueStartedBy"] = "%s hat den DLM Plündermeister gestartet. Dein DKP-Stand: %d",
            ["QueueStartAuctions"] = "Auktionen starten",
            ["QueueRemoveItem"] = "Gegenstand entfernen",
            ["QueueWatching"] = "Gegenstände plündern oder hierher ziehen.",
            ["QueueItemOpen"] = "1 Gegenstand offen",
            ["QueueItemsOpen"] = "%d Gegenstände offen",
            ["QueueInvalidItem"] = "Dieser Gegenstand kann nicht versteigert werden.",
            ["QueueShowPlayerList"] = "Spielerliste anzeigen",
            ["QueueEndLootMaster"] = "Plündermeister beenden",
            ["QueueEndLootMasterQuestion"] = "Soll der DLM Plündermeister wirklich beendet werden?",
            ["QueueShowItems"] = "Gegenstände anzeigen",
            -- auction
            ["Auction"] = "Auktion",
            ["AuctionStarted"] = "Auktion gestartet.",
            ["AuctionEndsIn"] = "Auktion endet in: ",
            -- stocks
            ["Stocks"] = "Kontostände",
            ["StocksStartTestAuction"] = "Auktion testen",
            ["StocksStart"] = "Start",
            ["StocksShowHistory"] = "Historie anzeigen",
            ["StocksShowHistoryOfPlayer"] = "Zeigt alle Auktionen, die dieser Spieler gewonnen hat.",
            ["StocksResetDkp"] = "DKP zurücksetzen",
            ["StocksResetDkpOfPlayer"] = "Setzt die DKP von %s abhängig der Bonus-DKP auf %d DKP.",
            ["StocksResetDkpOfPlayerQuestion"] = "Sollen die DKP von %s auf %d gesetzt werden?",
            ["StocksResetDkpOfPlayers"] = "Setzt die DKP aller Spieler abhängig deren Bonus-DKP auf %d - %d DKP.",
            ["StocksResetDkpOfPlayersQuestion"] = "Sollen die DKP aller Spieler abhängig deren Bonus-DKP auf %d - %d DKP gesetzt werden?",
            ["StocksCheckVersion"] = "Version prüfen",
            ["StocksCheckVersionAgain"] = "Addon Version von %s erneut prüfen.",
            ["StocksSharedDKP"] = "Geteilte DKP",
            ["StocksAssignMain"] = "Hauptcharakter zuweisen",
            ["StocksAssignMainDescription"] = "Wenn dieser Charakter ein Twink eines bereits bekannten Charakters ist, kann dieser als Twink dem Hauptcharakter zugewiesen werden. Der DKP-Stand wird dann zwischen den Charakteren geteilt.",
            ["StocksDetachTwink"] = "Twink trennen",
            ["StocksDetachTwinkDescription"] = "Wenn der DKP-Stand eines der Twinks nicht mehr mit dem Hauptcharakter geteilt werden soll, kann dieser herausgelöst und getrennt verwaltet oder gelöscht werden.",
            ["StocksRemovePlayer"] = "Spieler entfernen",
            ["StocksSelectMainCharacter"] = "Bitte wählen sie den Hauptcharakter aus, dem |cff00ff00%s|r als Twink zugewiesen werden soll.",
            ["StocksSelectTwink"] = "Bitte wählen sie den Twink aus, der von |cff00ff00%s|r getrennt werden soll.",
            ["StocksImportExport"] = "Importieren / Exportieren",
            ["StocksImportExportDescription"] = "Vorhandene Kontostände nach DLM importieren oder die aktuellen DLM-Kontostände exportieren.",
            -- settings
            ["Settings"] = "Plündermeister Einstellungen",
            ["SettingsDescription"] = "Festlegen, nach welchem System Gegenstände auktioniert werden sollen.",
            ["SettingsSystemGoldOnly"] = "Nur Gold",
            ["SettingsSystemGoldOnlyDescription"] = "Gegenstände werden nur für Gold auktioniert (GDKP). Es müssen keine DKP verwaltet werden.",
            ["SettingsSystemDkpOnly"] = "Nur DKP",
            ["SettingsSystemDkpOnlyDescription"] = "Gegenstände werden für DKP versteigert. Goldgebote sind nicht möglich.",
            ["SettingsSystemGoldAndDkp"] = "Gold & DKP",
            ["SettingsSystemGoldAndDkpDescription"] = "Gegenstände werden für Gold oder DKP versteigert. Sobald DKP geboten wurden, kann der Gegenstand nicht mehr mit Gold ersteigert werden.",
            ["SettingsGreedModeDisabled"] = "Deaktiviert",
            ["SettingsGreedModeDisabledDescription"] = "Main > Second wird nicht berücksichtigt.",
            ["SettingsGreedModeEnabled"] = "Aktiviert",
            ["SettingsGreedModeEnabledDescription"] = "Vor dem Versteigern werden die Spieler gefragt, ob der Gegenstand für deren Main oder Second Spec benötigt wird. Sobald ein Spieler mit Main Spec bietet, können Spieler mit Second Spec nicht mehr mitbieten.",
            ["SettingsGreedModeDkpOnly"] = "Nur bei DKP",
            ["SettingsGreedModeDkpOnlyDescription"] = "Vor dem Versteigern werden die Spieler gefragt, ob der Gegenstand für deren Main oder Second Spec benötigt wird. Sobald ein Spieler mit Main Spec DKP bietet, können Spieler mit Second Spec nicht mehr mitbieten. Gold kann beliebig von allen Spielern geboten werden.",
            ["SettingsGreedModeGoldAndDkp"] = "Bei DKP & Gold",
            ["SettingsGreedModeGoldAndDkpDescription"] = "Vor dem Versteigern werden die Spieler gefragt, ob der Gegenstand für deren Main oder Second Spec benötigt wird. Sobald ein Spieler mit Main Spec Gold oder DKP bietet, können Spieler mit Second Spec nicht mehr bieten.",
            ["SettingsGreedModeMainSpecDkpOnly"] = "Main Spec nur DKP",
            ["SettingsGreedModeMainSpecDkpOnlyDescription"] = "Vor dem Versteigern werden die Spieler gefragt, ob der Gegenstand für deren Main oder Second Spec benötigt wird. Spieler mit Main Spec müssen DKP bieten, Spieler mit Second Spec können auch Gold bieten, müssen aber passen, sobald von einem Spieler mit Main Spec DKP geboten werden.",
            ["SettingsDkpIncrease"] = "Erhöhung pro Gebot",
            ["SettingsDkpThreshold"] = "Bonus-DKP Schwelle",
            ["SettingsDkpThresholdDescription"] = "Definiert die Schwelle, ab der keine normalen DKP, sondern Bonus-DKP geboten werden müssen. Bonus-DKP werden immer in 1er Schritten geboten. Ab dieser Schwelle können mehrere Spieler die gleiche Anzahl DKP bieten. Der Sieger wird dann durch Würfeln ermittelt.",
            ["SettingsDkpMaxRaid"] = "Maximum pro Raid",
            ["SettingsDkpMaxRaidDescription"] = "Die Anzahl an Bonus-DKP, die ein Spieler während eines Raids maximal mitnehmen und ausgeben kann. Hiermit ist nicht die Anzahl an Bonus-DKP gemeint, die ein Spieler insgesammt ansparen kann.",
            --["SettingsDkpMaxSavable"] = "Maximal ansparbar",
            --["SettingsUnlimited"] = "Unbegrenzt",
            --["SettingsUnlimitedDescription"] = "Zeigt an, ob Spieler eine unbegrenzte Anzahl an Bonus-DKP ansparen können.",
            ["SettingsGoldMinBid"] = "Mindestgebot",
            ["SettingsGoldIncrease"] = "Erhöhung pro Gebot",
            ["SettingsMustCarryGold"] = "Spieler müssen das Gold bei sich tragen",
            ["SettingsMustCarryGoldDescription"] = "Zeigt an, ob das Addon das Inventar des Spielers überprüfen und nur Gold-Gebote akzeptieren soll, die der Spieler direkt bezahlen kann.",
            -- raid end
            ["RaidEnd"] = "Raidende",
            ["By"] = "von",
            ["All"] = "Alle",
            ["Yes"] = "Ja",
            ["No"] = "Nein",
            ["New"] = "Neu",
            ["Ok"] = "OK",
            ["Close"] = "Schließen"
        }
    };
end

-- register model
addon:RegisterModel(LocalesModel, "locales");
