--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define message
AuctionEndedMessage = {};
AuctionEndedMessage.__index = AuctionEndedMessage;
AuctionEndedMessage.prefix = "AuctionEnded";

-- create new message
function AuctionEndedMessage:Create(auction, lastBid)
    local message = {
        auctionId = auction.id,
        winner = auction.winner,
        gold = lastBid.gold,
        dkp = lastBid.dkp,
        isGreed = lastBid.isGreed
    }
    setmetatable(message, AuctionEndedMessage);
    return message;
end

-- parse message from string
function AuctionEndedMessage:Parse(value)
    -- get valuues
    local values = addon:GetService("message"):SplitString(value, ":");

    -- get winner
    local winner = nil;
    if (values[2] ~= "-") then
        winner = values[2];
    end

    -- build message
    local message = {
        auctionId = values[1],
        winner = winner,
        gold = tonumber(values[3]),
        dkp = tonumber(values[4]),
        isGreed = (tonumber(values[5]) == 1)
    }
    setmetatable(message, AuctionEndedMessage);
    return message;
end

-- convert message to string
function AuctionEndedMessage:ToString()
    return table.concat({
        self.auctionId,
        self.winner or "-",
        self.gold,
        self.dkp,
        (self.isGreed and "1" or "0")
    }, ":");
end

-- register model
addon:RegisterModel(AuctionEndedMessage, "auction-ended-message");
