--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define message
NewAuctionMessage = {};
NewAuctionMessage.__index = NewAuctionMessage;
NewAuctionMessage.prefix = "NewAuction";

-- Create message model.
function NewAuctionMessage:Create(auction, canBid, dkpStock)
    local message = {
        auctionId = auction.id,
        itemId = auction.item.id,
        goldMinimum = auction.goldMinimum,
        goldStep = auction.goldStep,
        mustCarryGold = auction.mustCarryGold,
        dkpStep = auction.dkpStep,
        dkpBonusRaidMaximum = auction.dkpBonusRaidMaximum,
        dkpThreshold = auction.dkpThreshold,
        bidTime = auction.bidTime,
        canBid = canBid,
        dkpStock = dkpStock,
        isTest = auction.isTest,
        greedMode = auction.greedMode
    };
    setmetatable(message, NewAuctionMessage);
    return message;
end

-- parse message from string
function NewAuctionMessage:Parse(value)
    local values = addon:GetService("message"):SplitString(value, ":");
    local message = {
        auctionId = values[1],
        itemId = tonumber(values[2]),
        goldMinimum = tonumber(values[3]),
        goldStep = tonumber(values[4]),
        mustCarryGold = (tonumber(values[5]) == 1),
        dkpStep = tonumber(values[6]),
        dkpBonusRaidMaximum = tonumber(values[7]),
        dkpThreshold = tonumber(values[8]),
        bidTime = tonumber(values[9]),
        canBid = (tonumber(values[10]) == 1),
        dkpStock = tonumber(values[11]),
        isTest = (tonumber(values[12]) == 1),
        greedMode = tonumber(values[13])
    }
    setmetatable(message, NewAuctionMessage);
    return message;
end

-- convert message to string
function NewAuctionMessage:ToString()
    return table.concat({
        self.auctionId,
        self.itemId,
        self.goldMinimum,
        self.goldStep,
        (self.mustCarryGold and "1" or "0"),
        self.dkpStep,
        self.dkpBonusRaidMaximum,
        self.dkpThreshold,
        self.bidTime,
        (self.canBid and "1" or "0"),
        self.dkpStock,
        (self.isTest and "1" or "0"),
        self.greedMode
    }, ":");
end

-- register model
addon:RegisterModel(NewAuctionMessage, "new-auction-message");
