--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define service
HistoryService = {};
HistoryService.__index = HistoryService;

--- Initialize service.
function HistoryService:Initialize()
    -- init database
    if (History == nil) then
        History = {}
    end
    self.view = nil;
end

--- Show history.
-- @param searchText Text to search for.
function HistoryService:ShowHistory(searchText)
    -- check if view must be created
    if (self.view == nil) then
        self.view = addon:CreateView("history");
    end

    -- show view
    self.view:Show(searchText);
end

--- Store auction.
-- @param auction Auction to store.
function HistoryService:StoreAuction(auction)
    -- clear participants
    auction.participants = nil;

    -- add to history
    table.insert(History, auction);
end

--- Remove auction.
-- @param auction Auction to remove.
function HistoryService:RemoveAuction(auction)
    for i, a in ipairs(History) do
        if (a.id == auction.id) then
            table.remove(History, i);
            return;
        end
    end
end

-- register service
addon:RegisterService(HistoryService, "history");
