--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define service
PlayerService = {};
PlayerService.__index = PlayerService;

-- get realm name
local realmName = string.gsub(GetRealmName(), "%s+", "");

--- Initialize service.
function PlayerService:Initialize()
    -- get player name
    self.current = self:CheckName(GetUnitName("player"));
end

-- get player short name
function PlayerService:GetShortName(name)
    -- split by "-"
    local parts = addon:GetService("message"):SplitString(name, "-");

    -- check if realm is same realm
    if (#parts > 1 and parts[2] == realmName) then
        -- only return player name
        return parts[1];
    end

    -- different realm, return full name
    return name;
end

-- check name and add realm if not set
function PlayerService:CheckName(name)
    -- check if name is null
    if (name == nil) then
        return nil;
    end

    -- check if realm already included
    if (string.find(name, "-") == nil) then
        name = name .. "-" .. realmName;
    end
    return name;
end

-- check if given player is current player
function PlayerService:IsCurrentPlayer(name)
    return self.current == self:CheckName(name);
end

-- check if current player is loot master
function PlayerService:CurrentIsLootMaster()
    return self:IsLootMaster(self.current);
end

-- check if given player is loot master
function PlayerService:IsLootMaster(player)
    -- check if alone
    if (GetNumGroupMembers() == 0) then
        return false;
    end

    -- get loot method
    local lootMethod, partyMasterLooterId, raidMasterLooterId = GetLootMethod();

    -- check if master llot set
    if (lootMethod ~= "master") then
        return false;
    end

    -- get player service
    local playerService = addon:GetService("player");

    -- check if is raid master looter
    if (raidMasterLooterId ~= nil and raidMasterLooterId > 0) then
        return player == playerService:CheckName(UnitName("raid" .. raidMasterLooterId));
        -- check if is yourself
    elseif (partyMasterLooterId ~= nil and partyMasterLooterId == 0) then
        return player == playerService.current;
        -- check if is party master looter
    elseif (partyMasterLooterId ~= nil and partyMasterLooterId > 0) then
        return player == playerService:CheckName(UnitName("party" .. partyMasterLooterId));
    end
    return false;
end

-- register service
addon:RegisterService(PlayerService, "player");
