--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define service
SettingsService = {};
SettingsService.__index = SettingsService;

--- Initialize service.
function SettingsService:Initialize()
    -- get models
    local BidSystem = addon:GetModel("bid-system");
    local GreedMode = addon:GetModel("greed-mode");

    -- init settings
    if (Settings == nil) then Settings = {} end
    if (Settings.system == nil) then Settings.system = BidSystem.GoldAndDkp end
    if (Settings.greedMode == nil) then Settings.greedMode = GreedMode.Disabled end
    if (Settings.bidTime == nil) then Settings.bidTime = 15 end
    if (Settings.gold == nil) then Settings.gold = {} end
    if (Settings.gold.minimum == nil) then Settings.gold.minimum = 50 end
    if (Settings.gold.step == nil) then Settings.gold.step = 50 end
    if (Settings.gold.mustCarry == nil) then Settings.gold.mustCarry = true end
    if (Settings.dkp == nil) then Settings.dkp = {} end
    if (Settings.dkp.step == nil) then Settings.dkp.step = 5 end
    if (Settings.dkp.threshold == nil) then Settings.dkp.threshold = 100 end
    if (Settings.dkp.bonusRaidMaximum == nil) then Settings.dkp.bonusRaidMaximum = 5 end
    if (Settings.dkp.bonusSavingMaximum == nil) then Settings.dkp.bonusSavingMaximum = 0 end

    -- prepare view
    self.view = nil;
end

--- Show settings view.
-- @param onUpdate Callback, triggered on settings update.
-- @param onClose Callback, triggered on settings view close.
function SettingsService:ShowSettings(onUpdate, onClose)
    -- check if view must be created
    if (self.view == nil) then
        self.view = addon:CreateView("settings");
    end

    -- show view
    self.view:Show(onUpdate, onClose);
end

--- Check if dkp enabled.
-- @return True, if DKP enabled.
function SettingsService:DkpEnabled()
    return Settings.system ~= 0;
end

-- register service
addon:RegisterService(SettingsService, "settings");
