--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define view
CopyView = {};
CopyView.__index = CopyView;

--- Show copy view.
-- @param title Title of view.
function CopyView:Show(name, title, description, value, showOkCancel, onOk, onClose)
    -- create view
    local uiService = addon:GetService("ui");
    local view = uiService:CreateView(name, 460, 360, title);
    self.view = view;
    self.onClose = onClose;

    -- add close button
    local closeButton = CreateFrame("Button", nil, view, "UIPanelCloseButton");
    closeButton:SetHeight(24);
    closeButton:SetWidth(24);
    closeButton:SetPoint("TOPRIGHT", -7, -7);
    closeButton:SetScript("OnClick", function()
        view:Hide()
    end);

    -- add summary text
    local descriptionText = view:CreateFontString(nil, "OVERLAY", "GameFontNormalSmall");
    descriptionText:SetPoint("TOPLEFT", 16, -30);
    descriptionText:SetTextColor(1, 1, 1);
    descriptionText:SetText(description);
    descriptionText:SetJustifyH("LEFT");

    -- create scroll frame 
    local scrollFrame, scrollChild = uiService:CreateScrollFrame(view);

    -- re-arrange scroll fame
    scrollFrame:SetPoint("TOPLEFT", 10, -56);
    scrollFrame:SetPoint("BOTTOMRIGHT", -10, 42);
    scrollChild:SetWidth(scrollFrame:GetWidth());
    scrollChild:SetHeight(2000);

    -- check if button text set
    if (showOkCancel) then
        scrollFrame:SetPoint("BOTTOMRIGHT", -10, 42);
    else
        scrollFrame:SetPoint("BOTTOMRIGHT", -10, 10);
    end

    -- add text box
    local textBox = CreateFrame("EditBox", nil, scrollChild);
    textBox:SetPoint("TOPLEFT", 0, 0);
    textBox:SetPoint("BOTTOMRIGHT", 0, 0);
    textBox:SetMultiLine(true);
    textBox:SetTextInsets(0, 0, 0, 0);
    textBox:SetFont("Fonts\\FRIZQT__.TTF", 10);
    textBox:EnableMouse(true);
    if (value ~= nil) then
        textBox:SetText(value);
    end

    -- check if ok cancel should be shown
    if (not showOkCancel) then
        return;
    end

    -- create cancel button
    local cancelButton = uiService:CreateButton(view, CANCEL, function()
        self:Close()
    end);
    cancelButton:SetPoint("BOTTOMRIGHT", -120, 10);
    cancelButton:SetWidth(100);
    cancelButton:SetHeight(28);

    -- create next button
    local okButton = uiService:CreateButton(view, addon:GetService("locale"):Get("Ok"), function()
        -- check if callback set
        if (onOk ~= nil) then
            -- trigger callback
            onOk(textBox:GetText());
        end

        -- close view
        self:Close();
    end);
    okButton:SetPoint("BOTTOMRIGHT", -10, 10);
    okButton:SetWidth(100);
    okButton:SetHeight(28);
end

--- Close view.
function CopyView:Close()
    -- hide view
    self.view:Hide();

    -- trigger callback
    if (self.onClose ~= nil) then
        self.onClose();
    end
end

-- register view
addon:RegisterView(CopyView, "copy");
