--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define view
RaidEndView = {};
RaidEndView.__index = RaidEndView;

-- show view
function RaidEndView:Show()
    -- get services
    local uiService = addon:GetService("ui");
    local localeService = addon:GetService("locale");
    local groupService = addon:GetService("group");
    local playerService = addon:GetService("player");

    -- check if view created
    if (self.view == nil) then
        -- prepare visible player list
        self.visiblePlayers = {};

        -- create view
        local view = uiService:CreateView("DLMRaidEnd", 600, 400, localeService:Get("RaidEnd"))
        self.view = view;

        -- add close button
        local closeButton = CreateFrame("Button", nil, view, "UIPanelCloseButton");
        closeButton:SetHeight(24);
        closeButton:SetWidth(24);
        closeButton:SetPoint("TOPRIGHT", -5, -5);
        closeButton:SetScript("OnClick", function()
            view:Hide();
        end);

        -- create scroll frame 
        local scrollFrame, scrollChild = uiService:CreateScrollFrame(view);
        scrollFrame:SetPoint("TOPLEFT", 10, -56);
        scrollFrame:SetPoint("BOTTOMRIGHT", -12, 42);
        scrollChild:SetWidth(scrollFrame:GetWidth());
        self.scrollFrame = scrollFrame;
        self.scrollChild = scrollChild;
    end

    -- remove player frames
    for i in pairs(self.visiblePlayers) do
        self.visiblePlayers[i].frame:Hide();
        self.visiblePlayers[i] = nil;
    end

    -- get all current player names
    local currentPlayerNames = groupService:GetCurrentPlayerNames();
    local players = {};

    -- add current players
    for i, playerName in ipairs(currentPlayerNames) do
        table.insert(players, {
            name = playerName,
            kills = {}
        });
    end

    -- iterate all kills
    for bossName, playerNames in pairs(Kills) do
        -- iterate all players
        for i, playerName in ipairs(playerNames) do
            -- preapre boss added
            local bossAdded = false;

            -- iterate existing player
            for i, existingPlayer in ipairs(players) do
                if (existingPlayer.name == playerName) then
                    table.insert(existingPlayer.kills, bossName);
                    bossAdded = true;
                    break;
                end
            end

            -- check if not added
            if (not bossAdded) then
                table.insert(players, {
                    name = playerName,
                    kills = { bossName }
                });
            end
        end
    end

    -- iterate players
    for i, player in ipairs(players) do
        -- get index
        local index = #self.visiblePlayers + 1;

        -- create frame
        local playerFrame = CreateFrame("Button", nil, self.scrollChild, BackdropTemplateMixin and "BackdropTemplate");
        local top = (index - 1) * 20;
        playerFrame:SetPoint("TOPLEFT", 0, -top);
        playerFrame:SetPoint("BOTTOMRIGHT", self.scrollChild, "TOPRIGHT", -28, -(top + 20));
        playerFrame:SetBackdrop({
            bgFile = [[Interface\Buttons\WHITE8x8]]
        });
        playerFrame.index = index;

        -- add frame to frames
        table.insert(self.visiblePlayers, {
            frame = playerFrame,
            player = player
        });

        -- check odd index
        if (index - math.floor(index / 2) * 2 == 0) then
            playerFrame:SetBackdropColor(0.1, 0.1, 0.1, 0.8);
        else
            playerFrame:SetBackdropColor(0.15, 0.15, 0.15, 0.8);
        end

        -- add date text
        local playerText = playerFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        playerText:SetPoint("TOPLEFT", 6, -4);
        playerText:SetPoint("BOTTOMRIGHT", playerFrame, "BOTTOMLEFT", 110, -4);
        playerText:SetJustifyH("LEFT");
        playerText:SetJustifyV("TOP");
        playerText:SetTextColor(1, 1, 1);
        playerText:SetText(playerService:GetShortName(player.name));

        -- add date text
        local bossText = playerFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        bossText:SetPoint("TOPLEFT", 120, -4);
        bossText:SetPoint("BOTTOMRIGHT", playerFrame, "BOTTOMRIGHT", 200, -4);
        bossText:SetJustifyH("LEFT");
        bossText:SetJustifyV("TOP");
        bossText:SetText(table.concat(player.kills, ", "));
    end

    -- set scroll height
    self.scrollChild:SetHeight(#self.visiblePlayers * 20);

    -- show view
    self.view:Show();
end

-- register view
addon:RegisterView(RaidEndView, "raid-end");
