--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define view
StocksDetachCharacterView = {};
StocksDetachCharacterView.__index = StocksDetachCharacterView;

--- Show view.
-- @param stock Stock with multiple characters to assign to detach one character from.
-- @param selectedName Pre selected name of twink.
-- @param callback Callback function which is triggered after successful detach.
-- @param parent Parent view.
function StocksDetachCharacterView:Show(stock, selectedName, callback, parent)
    -- get services
    local uiService = addon:GetService("ui");
    local localeService = addon:GetService("locale");
    local playerService = addon:GetService("player");

    -- store stock
    self.currentStock = stock;
    self.currentSelectedIndex = nil;

    -- create view
    local view = uiService:CreateView("DLMStocksDetachTwink", 320, 160, localeService:Get("StocksDetachTwink"));
    view:SetPoint("CENTER", parent, "CENTER", 0, 0);
    self.view = view;

    -- add select text
    local selectText = view:CreateFontString(nil, "OVERLAY", "GameFontNormal");
    selectText:SetPoint("TOPLEFT", 16, -28);
    selectText:SetPoint("BOTTOMRIGHT", view, "TOPRIGHT", -16, -80);
    selectText:SetText(localeService:Get("StocksSelectTwink", playerService:GetShortName(stock.players[1])));
    selectText:SetJustifyH("LEFT");
    selectText:SetTextColor(1, 1, 1);

    -- add character drop down
    local characterSelection = CreateFrame("Frame", nil, view, "UIDropDownMenuTemplate");
    characterSelection:SetPoint("TOPLEFT", -4, -80);
    characterSelection:SetWidth(40);
    UIDropDownMenu_Initialize(characterSelection, function()
        -- get all characters from stock
        for i = 2, #stock.players do
            -- add entry
            local shortName = playerService:GetShortName(stock.players[i]);
            UIDropDownMenu_AddButton({
                text = shortName,
                notCheckable = true,
                func = function()
                    UIDropDownMenu_SetText(characterSelection, shortName);
                    self.currentSelectedIndex = i;
                end
            });

            -- check if is selected name
            if ((selectedName == nil and i == 2) or (selectedName ~= nil and selectedName == shortName)) then
                UIDropDownMenu_SetText(characterSelection, shortName);
                self.currentSelectedIndex = i;
            end
        end
    end);

    -- create cancel button
    local cancelButton = uiService:CreateButton(view, CANCEL, function()
        -- hide view
        view:Hide();
        parent:Show();
    end);
    cancelButton:SetPoint("BOTTOMRIGHT", -120, 10);
    cancelButton:SetWidth(100);
    cancelButton:SetHeight(28);

    -- create ok button
    local okButton = uiService:CreateButton(view, "OK", function()
        -- check current selected stock
        local selectedCharacter = UIDropDownMenu_GetText(characterSelection);
        if (self.currentSelectedIndex ~= nil) then
            -- get player name
            local playerName = self.currentStock.players[self.currentSelectedIndex];

            -- remove twink
            table.remove(self.currentStock.players, self.currentSelectedIndex);

            -- add new stocks
            addon:GetService("stocks"):GetStock(playerName);
        end

        -- trigger callback
        callback();

        -- hide view
        view:Hide();
        parent:Show();
    end);
    okButton:SetPoint("BOTTOMRIGHT", -10, 10);
    okButton:SetWidth(100);
    okButton:SetHeight(28);

    parent:Hide();
    return view;
end

-- register view
addon:RegisterView(StocksDetachCharacterView, "stocks-detach-character");
