--[[

@author Esperanza - Everlook/EU-Alliance
@copyright ©2021 The DKP Loot Master Authors. All Rights Reserved.

Licensed under the GNU General Public License, Version 3.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS-IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]
local addon = _G.dkpLootMaster;

-- define view
StocksView = {};
StocksView.__index = StocksView;

-- show view
function StocksView:Show(canStartQueue)
    -- check if queue can be started
    if (canStartQueue) then
        self.canStartQueue = true;
    elseif (self.canStartQueue == nil) then
        self.canStartQueue = false;
    end

    -- get services
    local uiService = addon:GetService("ui");
    local localeService = addon:GetService("locale");

    -- check if view created
    if (self.view == nil) then
        -- prepare visible rows list
        self.visibleRows = {};

        -- create view
        local view = uiService:CreateView("DLMSettingsStocks", 460, 360, localeService:Get("Stocks"));
        self.view = view;

        -- add close button
        local closeButton = CreateFrame("Button", nil, view, "UIPanelCloseButton");
        closeButton:SetHeight(24);
        closeButton:SetWidth(24);
        closeButton:SetPoint("TOPRIGHT", -7, -7);
        closeButton:SetScript("OnClick", function()
            self.canStartQueue = false;
            view:Hide();
        end);

        -- add player search box
        local playerSearch = CreateFrame("EditBox", nil, view, "InputBoxTemplate");
        playerSearch:SetPoint("TOPLEFT", 17, -40);
        playerSearch:SetHeight(20);
        playerSearch:SetWidth(250);
        playerSearch:SetAutoFocus(false);
        playerSearch:SetScript("OnTextChanged", function()
            self:AddPlayers();
        end);
        playerSearch:Hide();
        self.playerSearch = playerSearch;
        local playerStopSearchButton = CreateFrame("Button", nil, view, "UIPanelCloseButton");
        playerStopSearchButton:SetHeight(32);
        playerStopSearchButton:SetWidth(32);
        playerStopSearchButton:SetPoint("TOPLEFT", 261, -34);
        playerStopSearchButton:Hide();

        -- add player text
        local playerTextButton = CreateFrame("Frame", nil, view); -- view:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        playerTextButton:SetPoint("TOPLEFT", 21, -46);
        playerTextButton:SetHeight(20);
        playerTextButton:SetWidth(240);
        local playerText = playerTextButton:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        playerText:SetPoint("TOPLEFT", 0, 0);
        playerText:SetText(localeService:Get("Players"));

        -- register search events
        playerTextButton:SetScript("OnEnter", function()
            playerText:SetTextColor(1, 1, 1);
        end);
        playerTextButton:SetScript("OnLeave", function()
            playerText:SetTextColor(GameFontNormal:GetTextColor());
        end);
        playerTextButton:SetScript("OnMouseDown", function()
            playerTextButton:Hide();
            playerStopSearchButton:Show();
            playerSearch:Show();
            playerSearch:SetFocus();
        end);
        playerStopSearchButton:SetScript("OnClick", function()
            playerTextButton:Show();
            playerStopSearchButton:Hide();
            playerSearch:Hide();
            playerSearch:SetText("");
            self:AddPlayers();
        end);

        -- add dkp headline
        local dkpHeadline = view:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        dkpHeadline:SetPoint("TOPRIGHT", -194, -46);
        dkpHeadline:SetText(localeService:Get("Dkp"));
        self.dkpHeadline = dkpHeadline;

        -- add bonus dkp headline
        local bonusDkpHeadline = view:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        bonusDkpHeadline:SetPoint("TOPRIGHT", -99, -46);
        bonusDkpHeadline:SetText(localeService:Get("BonusDkp"));
        self.bonusDkpHeadline = bonusDkpHeadline;

        -- add version headline
        local versionHeadline = view:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        versionHeadline:SetPoint("TOPRIGHT", -39, -46);
        versionHeadline:SetText(localeService:Get("Version"));
        self.versionHeadline = versionHeadline;

        -- create scroll frame 
        local scrollFrame, scrollChild = uiService:CreateScrollFrame(view);
        scrollFrame:SetPoint("TOPLEFT", 10, -64);
        scrollFrame:SetPoint("BOTTOMRIGHT", -12, 42);
        scrollChild:SetWidth(scrollFrame:GetWidth());
        self.scrollChild = scrollChild;

        -- create settings button
        local settingsButton = uiService:CreateIconButton(view, "Trade_engineering", localeService:Get("Settings"),
                                   localeService:Get("SettingsDescription"), function()
            -- show settings
            addon:GetService("settings"):ShowSettings(function()
                self:AddPlayers()
            end, function()
                -- restore position and show view
                uiService:RestorePosition(self.view);
                self.view:Show()
            end);
            self.view:Hide();
        end);
        settingsButton:SetPoint("BOTTOMLEFT", 12, 13);

        -- create import / export button
        self.importButton = uiService:CreateIconButton(view, "inv_misc_note_06", localeService:Get("StocksImportExport"),
                                localeService:Get("StocksImportExportDescription"), function()
                -- show import
                addon:GetService("stocks"):ShowImport(function()
                    self:AddPlayers()
                end, function()
                    -- restore position and show view
                    uiService:RestorePosition(self.view);
                    self.view:Show()
                end);
                self.view:Hide();
            end);
        self.importButton:SetPoint("BOTTOMLEFT", 40, 13);

        -- create reset button
        self.resetButton = uiService:CreateIconButton(view, "Spell_holy_renew", localeService:Get("StocksResetDkp"), "",
                               function()
                addon:CreateView("confirmation"):Show(
                    localeService:Get("StocksResetDkp"),
                    localeService:Get("StocksResetDkpOfPlayersQuestion", Settings.dkp.threshold,
                        Settings.dkp.threshold + Settings.dkp.bonusRaidMaximum), 
                    function()
                        -- reset dkp and refresh stocks
                        addon:GetService("stocks"):ResetDkp();
                        self:AddPlayers();
                    end
                );
            end);
        self.resetButton:SetPoint("BOTTOMLEFT", 68, 13);

        -- create test button
        self.testButton = uiService:CreateButton(view, localeService:Get("StocksStartTestAuction"), function()
            self:StartTestAuction();
        end);
        self.testButton:SetPoint("BOTTOMRIGHT", -120, 10);
        self.testButton:SetWidth(120);
        self.testButton:SetHeight(28);

        -- create start button
        self.startButton = uiService:CreateButton(view, localeService:Get("StocksStart"), function()
            if (self.canStartQueue) then
                addon:GetService("group"):NotifyAllAddonRequired();
                addon:GetService("queue"):StartLootWatch(true);
            end
            self.canStartQueue = false;
            self.view:Hide();
        end);
        self.startButton:SetPoint("BOTTOMRIGHT", -10, 10);
        self.startButton:SetWidth(100);
        self.startButton:SetHeight(28);
    else
        self.view:Show();
    end

    -- restore position
    uiService:RestorePosition(self.view);

    -- add players
    self:AddPlayers();

    -- show / hide buttons
    if (self.canStartQueue) then
        self.view.titleLabel:SetText(addon.shortcut .. localeService:Get("StartMasterLooter"));
        self.startButton:SetText(localeService:Get("StocksStart"));
        self.testButton:Show();
        self.dkpHeadline:SetPoint("TOPRIGHT", -194, -46);
        self.bonusDkpHeadline:SetPoint("TOPRIGHT", -99, -46);
        self.versionHeadline:Show();
    else
        self.view.titleLabel:SetText(addon.shortcut .. localeService:Get("Stocks"));
        self.startButton:SetText(localeService:Get("Ok"));
        self.testButton:Hide();
        self.dkpHeadline:SetPoint("TOPRIGHT", -134, -46);
        self.bonusDkpHeadline:SetPoint("TOPRIGHT", -39, -46);
        self.versionHeadline:Hide();
    end
end

--- Add players.
function StocksView:AddPlayers()
    -- remove player frames
    for i in pairs(self.visibleRows) do
        self.visibleRows[i].frame:Hide();
        self.visibleRows[i] = nil;
    end

    -- get locale service and date format
    local localeService = addon:GetService("locale");
    local playerService = addon:GetService("player");
    local dateFormat = localeService:GetBare("DateFormat");

    -- check if dkp enabled
    local dkpEnabled = addon:GetService("settings"):DkpEnabled();
    if (dkpEnabled) then
        self.dkpHeadline:Show();
        self.bonusDkpHeadline:Show();
        self.importButton:Show();
        self.resetButton.tooltipText = localeService:Get("StocksResetDkpOfPlayers", Settings.dkp.threshold,
                                           Settings.dkp.threshold + Settings.dkp.bonusRaidMaximum);
        self.resetButton:Show();
    else
        self.dkpHeadline:Hide();
        self.bonusDkpHeadline:Hide();
        self.importButton:Hide();
        self.resetButton:Hide();
    end

    -- get players
    self.players = {};
    if (self.canStartQueue or addon:GetService("queue").watching) then
        -- add all players of group
        local goldOnly = Settings.system == addon:GetModel("bid-system").GoldOnly;
        local stocksService = addon:GetService("stocks");
        for i, player in ipairs(addon:GetService("group"):GetCurrentPlayers()) do
            -- get stock
            local stock = stocksService:GetStock(player.name);

            -- check if player is not main character
            local playerText = nil;
            local twinkName = nil;
            if (player.name == stock.players[1] or goldOnly) then
                playerText = "|cffffffff" .. playerService:GetShortName(player.name);
            else
                twinkName = playerService:GetShortName(player.name);
                playerText =
                    string.format("|cffffffff%s|r: %s", twinkName, playerService:GetShortName(stock.players[1]));
            end

            -- add player
            table.insert(self.players, {
                name = player.name,
                text = playerText,
                twinkName = twinkName,
                version = player.version,
                versionTimeout = player.versionTimeout,
                stock = stock
            });
        end
    else
        -- add global stocks
        for i, stock in ipairs(Stocks) do
            -- add player
            table.insert(self.players, {
                name = stock.players[1],
                stock = stock,
                versionTimeout = false
            });
        end
    end

    -- get all character names
    for i, player in ipairs(self.players) do
        -- get names of all chracters
        local allCharacterNames = {};
        for i, characterName in ipairs(player.stock.players) do
            table.insert(allCharacterNames, playerService:GetShortName(characterName));
        end
        player.allCharacterNames = table.concat(allCharacterNames, ", ");

        -- set all anmes as player name if not set yet
        if (player.text == nil) then
            player.text = player.allCharacterNames;
        end
    end

    -- sort players
    table.sort(self.players, function(a, b)
        return a.name < b.name;
    end);

    -- get search text
    local searchText = string.gsub(string.lower(self.playerSearch:GetText()), "%-", "%%-");

    -- add stocks
    for i, player in ipairs(self.players) do
        -- check search text
        if (searchText == nil or string.find(string.lower(player.allCharacterNames), searchText) ~= nil) then
            -- add player
            self:AddPlayer(player, dkpEnabled, localeService);
        end
    end

    -- set scroll height
    self.scrollChild:SetHeight(#self.visibleRows * 20);
end

--- Add player.
function StocksView:AddPlayer(player, dkpEnabled, localeService)
    -- get index and stock
    local index = #self.visibleRows + 1;
    local stock = player.stock;

    -- create frame
    local stockFrame = CreateFrame("Button", nil, self.scrollChild, BackdropTemplateMixin and "BackdropTemplate");
    local top = (index - 1) * 20;
    stockFrame:SetPoint("TOPLEFT", 0, -top);
    stockFrame:SetPoint("BOTTOMRIGHT", self.scrollChild, "TOPRIGHT", -28, -(top + 20));
    stockFrame:SetBackdrop({
        bgFile = [[Interface\Buttons\WHITE8x8]]
    });

    -- check odd index
    if (index - math.floor(index / 2) * 2 == 0) then
        stockFrame:SetBackdropColor(0.1, 0.1, 0.1, 0.8);
    else
        stockFrame:SetBackdropColor(0.15, 0.15, 0.15, 0.8);
    end

    -- create event functions
    local omEnterRow = function()
        -- update background color
        stockFrame:SetBackdropColor(0.3, 0.3, 0.3, 0.8);
    end;
    local onLeaveRow = function()
        -- update background color
        if (index - math.floor(index / 2) * 2 == 0) then
            stockFrame:SetBackdropColor(0.1, 0.1, 0.1, 0.8);
        else
            stockFrame:SetBackdropColor(0.15, 0.15, 0.15, 0.8);
        end
    end;

    -- add player text
    local playerText = stockFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal");
    playerText:SetPoint("TOPLEFT", 6, -4);
    playerText:SetPoint("BOTTOMRIGHT", stockFrame, "BOTTOMRIGHT", (dkpEnabled and -190 or -66), 0);
    playerText:SetJustifyH("LEFT");
    playerText:SetJustifyV("TOP");
    playerText:SetText(player.text);

    -- check if dkp enabled
    local dkpText;
    if (dkpEnabled) then
        -- add minus button
        local minusButton = CreateFrame("Button", nil, stockFrame, "UIPanelButtonTemplate");
        minusButton:SetText("-");
        minusButton:SetWidth(20);
        minusButton:SetHeight(17);
        minusButton:Hide();

        -- add plus button
        local plusButton = CreateFrame("Button", nil, stockFrame, "UIPanelButtonTemplate");
        plusButton:SetText("+");
        plusButton:SetWidth(20);
        plusButton:SetHeight(17);
        plusButton:Hide();

        -- add dkp text
        local dkpTextButton = CreateFrame("Button", nil, stockFrame);
        dkpTextButton:SetPoint("TOPRIGHT", (self.canStartQueue and -160 or -100), 0);
        dkpTextButton:SetHeight(20);
        dkpTextButton:SetWidth(94);
        dkpText = dkpTextButton:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        dkpText:SetPoint("TOPRIGHT", 0, -4);
        dkpText:SetTextColor(1, 1, 1);
        dkpText:SetText(stock.dkp);

        -- handle dkp mouse enter
        dkpTextButton:SetScript("OnEnter", function()
            omEnterRow();
            minusButton:SetPoint("TOPLEFT", dkpTextButton, "TOPLEFT", 20, 0);
            minusButton:Show();
            minusButton:SetFrameLevel(10000);
            minusButton.bonusDkp = false;
            plusButton:SetPoint("TOPLEFT", dkpTextButton, "TOPLEFT", 40, 0);
            plusButton:Show();
            plusButton:SetFrameLevel(10000);
            plusButton.bonusDkp = false;
        end);

        -- handle dlp mouse leave
        dkpTextButton:SetScript("OnLeave", function()
            onLeaveRow();
            minusButton:Hide();
            plusButton:Hide();
        end);

        -- add bonus dkp text
        local bonusDkpTextButton = CreateFrame("Button", nil, stockFrame);
        bonusDkpTextButton:SetPoint("TOPRIGHT", (self.canStartQueue and -66 or -6), 0);
        bonusDkpTextButton:SetHeight(20);
        bonusDkpTextButton:SetWidth(94);
        local bonusDkpText = bonusDkpTextButton:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        bonusDkpText:SetPoint("TOPRIGHT", 0, -4);
        bonusDkpText:SetTextColor(1, 1, 1);
        bonusDkpText:SetText(stock.isNew and ("|cff00ff00" .. localeService:Get("New") .. "!") or stock.bonusDkp);

        -- handle dkp mouse enter
        bonusDkpTextButton:SetScript("OnEnter", function()
            omEnterRow();
            minusButton:SetPoint("TOPLEFT", bonusDkpTextButton, "TOPLEFT", 20, 0);
            minusButton:Show();
            minusButton:SetFrameLevel(10000);
            minusButton.bonusDkp = true;
            plusButton:SetPoint("TOPLEFT", bonusDkpTextButton, "TOPLEFT", 40, 0);
            plusButton:Show();
            plusButton:SetFrameLevel(10000);
            plusButton.bonusDkp = true;
        end);

        -- handle dlp mouse leave
        bonusDkpTextButton:SetScript("OnLeave", function()
            onLeaveRow();
            minusButton:Hide();
            plusButton:Hide();
        end);

        -- set button events
        minusButton:SetScript("OnEnter", function()
            omEnterRow();
            minusButton:Show();
            plusButton:Show();
        end);
        minusButton:SetScript("OnLeave", function()
            onLeaveRow();
            minusButton:Hide();
            plusButton:Hide();
        end);
        minusButton:SetScript("OnClick", function()
            if (minusButton.bonusDkp) then
                stock.bonusDkp = math.max(0, stock.bonusDkp - 1);
                stock.dkp = math.min(Settings.dkp.threshold + stock.bonusDkp, stock.dkp);
                bonusDkpText:SetText(stock.bonusDkp);
                dkpText:SetText(stock.dkp);
            else
                stock.dkp = math.max(0, stock.dkp - (stock.dkp > Settings.dkp.threshold and 1 or Settings.dkp.step));
                dkpText:SetText(stock.dkp);
            end
            stock.isNew = false;
        end);
        plusButton:SetScript("OnEnter", function()
            omEnterRow();
            minusButton:Show();
            plusButton:Show();
        end);
        plusButton:SetScript("OnLeave", function()
            onLeaveRow();
            minusButton:Hide();
            plusButton:Hide();
        end);
        plusButton:SetScript("OnClick", function()
            if (minusButton.bonusDkp) then
                stock.bonusDkp = stock.bonusDkp + 1;
                bonusDkpText:SetText(stock.bonusDkp);
            else
                stock.dkp = math.min(Settings.dkp.threshold + math.min(Settings.dkp.bonusRaidMaximum, stock.bonusDkp), stock.dkp + (stock.dkp >= Settings.dkp.threshold and 1 or Settings.dkp.step));
                dkpText:SetText(stock.dkp);
            end
            stock.isNew = false;
        end);
    end

    -- check queue
    local versionText = nil;
    if (self.canStartQueue) then
        -- add version text
        versionText = stockFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal");
        versionText:SetPoint("TOPRIGHT", -6, -4);
        versionText:SetText(player.version and player.version or (player.versionTimeout and "X" or "?"));

        -- check version
        if (player.version == addon.version) then
            versionText:SetTextColor(1, 1, 1);
        elseif (player.versionTimeout) then
            versionText:SetTextColor(1, 0, 0);
        elseif (player.version == nil) then
            versionText:SetTextColor(0.6, 0.6, 0.6);
        else
            versionText:SetTextColor(1, 0.53, 0);
        end
    end

    -- add visible row
    table.insert(self.visibleRows, {
        frame = stockFrame,
        version = versionText,
        player = player
    });

    -- handle row mouse enter and leave
    stockFrame:SetScript("OnEnter", omEnterRow);
    stockFrame:SetScript("OnLeave", onLeaveRow);

    -- handle click event
    stockFrame:SetScript("OnMouseDown", function(_, button)
        -- check right button
        if (button ~= "RightButton") then
            return;
        end

        -- get stocks service
        local stocksService = addon:GetService("stocks");

        -- get player name
        local playerShortName = addon:GetService("player"):GetShortName(player.name);

        -- create context menu
        local contextMenu = CreateFrame("Frame", "DLMStocks_ContextMenu", UIParent, "UIDropDownMenuTemplate");
        UIDropDownMenu_Initialize(contextMenu, function(_self, level)
            -- add main entries
            UIDropDownMenu_AddButton({
                text = playerShortName,
                isTitle = true,
                notCheckable = true
            });

            UIDropDownMenu_AddButton({
                text = localeService:Get("StocksShowHistory"),
                tooltipTitle = localeService:Get("StocksShowHistory"),
                tooltipText = localeService:Get("StocksShowHistoryOfPlayer"),
                tooltipOnButton = true,
                notCheckable = true,
                func = function()
                    addon:GetService("history"):ShowHistory(player.allCharacterNames);
                end
            });

            -- check can start queue
            if (self.canStartQueue) then
                UIDropDownMenu_AddButton({
                    text = localeService:Get("StocksCheckVersion"),
                    tooltipTitle = localeService:Get("StocksCheckVersion"),
                    tooltipText = localeService:Get("StocksCheckVersionAgain", playerShortName),
                    tooltipOnButton = true,
                    notCheckable = true,
                    func = function()
                        -- check player
                        local groupService = addon:GetService("group");
                        groupService:CheckPlayer(player.name, true);

                        -- reset text
                        versionText:SetText("?");
                        versionText:SetTextColor(0.6, 0.6, 0.6);
                        groupService:WaitForChecks();
                    end
                });
            end

            if (dkpEnabled) then
                local resetDkp = Settings.dkp.threshold + math.min(stock.bonusDkp, Settings.dkp.bonusRaidMaximum);
                UIDropDownMenu_AddButton({
                    text = localeService:Get("StocksResetDkp"),
                    tooltipTitle = localeService:Get("StocksResetDkp"),
                    tooltipText = localeService:Get("StocksResetDkpOfPlayer", playerShortName, resetDkp),
                    tooltipOnButton = true,
                    notCheckable = true,
                    func = function()
                        addon:CreateView("confirmation"):Show(
                            localeService:Get("StocksResetDkp"),
                            localeService:Get("StocksResetDkpOfPlayerQuestion", playerShortName, resetDkp),
                            function()
                                addon:GetService("stocks"):ResetDkp(stock);
                                dkpText:SetText(stock.dkp);
                            end
                        );
                    end
                });

                -- add empty entry
                UIDropDownMenu_AddButton({
                    text = nil,
                    disabled = true
                });

                -- add sahred dkp entries
                UIDropDownMenu_AddButton({
                    text = localeService:Get("StocksSharedDKP"),
                    isTitle = true,
                    notCheckable = true
                });
                UIDropDownMenu_AddButton({
                    text = localeService:Get("StocksAssignMain"),
                    tooltipTitle = localeService:Get("StocksAssignMain"),
                    tooltipText = localeService:Get("StocksAssignMainDescription"),
                    tooltipOnButton = true,
                    disabled = #stock.players > 1,
                    notCheckable = true,
                    func = function()
                        addon:GetService("stocks"):AssignMainCharacter(stock, function()
                            self:AddPlayers();
                        end, self.view);
                    end
                });
                UIDropDownMenu_AddButton({
                    text = localeService:Get("StocksDetachTwink"),
                    tooltipTitle = localeService:Get("StocksDetachTwink"),
                    tooltipText = localeService:Get("StocksDetachTwinkDescription"),
                    tooltipOnButton = true,
                    disabled = #stock.players < 2,
                    notCheckable = true,
                    func = function()
                        addon:GetService("stocks"):DetachCharacter(stock, player.twinkName, function()
                            self:AddPlayers();
                        end, self.view);
                    end
                });
            end

            -- add remove entry if not start window
            if (not self.canStartQueue) then
                -- add empty entry
                UIDropDownMenu_AddButton({
                    text = nil,
                    disabled = true
                });

                -- add remove entry menu
                UIDropDownMenu_AddButton({
                    text = localeService:Get("StocksRemovePlayer"),
                    colorCode = "|cffff0000",
                    notCheckable = true,
                    func = function()
                        addon:GetService("stocks"):RemoveStock(stock);
                        self:AddPlayers();
                    end
                });
            end
        end, "MENU");

        ToggleDropDownMenu(1, nil, contextMenu, stockFrame, 0, 0);
    end);
end

--- Update version of player.
function StocksView:UpdateVersion(playerName, version)
    -- check rows
    for i, row in ipairs(self.visibleRows) do
        -- check player name
        if (row.player.name == playerName) then
            -- check version
            if (row.version == nil) then
                return;
            end

            -- set version
            row.version:SetText(version);

            -- check version
            if (version == addon.version) then
                row.version:SetTextColor(1, 1, 1);
            else
                row.version:SetTextColor(1, 0.53, 0);
            end
            break
        end
    end
end

--- Start test auction.
function StocksView:StartTestAuction()
    -- get item id
    local itemIndex = random(1, 7);
    local itemId = nil;

    if (itemIndex == 1) then
        itemId = 18233;
    elseif (itemIndex == 2) then
        itemId = 1177;
    elseif (itemIndex == 3) then
        itemId = 18230;
    elseif (itemIndex == 4) then
        itemId = 18228;
    elseif (itemIndex == 5) then
        itemId = 5263;
    elseif (itemIndex == 6) then
        itemId = 22174;
    elseif (itemIndex == 7) then
        itemId = 20221;
    end

    -- get item
    local item = Item:CreateFromItemID(itemId);

    -- wait until loaded
    item:ContinueOnItemLoad(function()
        local participants = {};
        for i, playerName in ipairs(addon:GetService("group"):GetCurrentPlayerNames()) do
            table.insert(participants, {
                name = playerName,
                canBid = true
            });
        end

        -- create loot
        local loot = addon:GetModel("loot"):Create("Manual", -1, itemId, item:GetItemLink(), item:GetItemIcon(), participants);

        -- start auction
        addon:GetService("auction"):StartAuction(loot, self, true);
    end);
end

-- Version of player has timed out.
function StocksView:VersionTimeout(playerName)
    -- check rows
    for i, row in ipairs(self.visibleRows) do
        -- check player name
        if (row.player.name == playerName) then
            -- check version
            if (row.version == nil) then
                return;
            end

            -- set x as text
            row.version:SetText("X");
            row.version:SetTextColor(1, 0, 0);
            break
        end
    end
end

-- register view
addon:RegisterView(StocksView, "stocks");
